@@ -11,7 +11,7 @@ use Pod::Usage ();
 use Cwd 'abs_path';
 use Config;
 
-our $VERSION = '0.117';
+our $VERSION = '0.118';
 
 sub new {
     my ($class, %option) = @_;
@@ -134,6 +134,7 @@ sub cmd_install {
         target_perl => $self->{target_perl},
     );
     my $menlo_base = "$ENV{HOME}/.perl-cpm/work";
+    my $menlo_cache = "$ENV{HOME}/.perl-cpm/cache";
     my $menlo_build_log = "$ENV{HOME}/.perl-cpm/build.@{[time]}.log";
     my $cb = sub {
         my ($read_fh, $write_fh) = @_;
@@ -144,6 +145,7 @@ sub cmd_install {
             read_fh => $read_fh, write_fh => $write_fh,
             ($self->{global} ? () : (local_lib => $self->{local_lib})),
             menlo_base => $menlo_base, menlo_build_log => $menlo_build_log,
+            menlo_cache => $menlo_cache,
             notest => $self->{notest},
         );
         $worker->run_loop;
